==> percona-server-mongodb_4.4.16.orig.tar.gz: percona-server-mongodb-4.4.16-16/src/mongo/db/exec/shard_filterer_impl.h <==
/**
 *    Copyright (C) 2019-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/db/exec/shard_filterer.h"
#include "mongo/db/matcher/matchable.h"
#include "mongo/db/s/scoped_collection_metadata.h"

namespace mongo {

class ShardFiltererImpl : public ShardFilterer {
public:
    ShardFiltererImpl(ScopedCollectionFilter collectionFilter);

    DocumentBelongsResult documentBelongsToMe(const WorkingSetMember& wsm) const override;
    DocumentBelongsResult documentBelongsToMe(const Document& doc) const override;

    bool isCollectionSharded() const override {
        return _collectionFilter.isSharded();
    }

    const KeyPattern& getKeyPattern() const override {
        invariant(_keyPattern);
        return _keyPattern->getKeyPattern();
    }

private:
    DocumentBelongsResult _shardKeyBelongsToMe(BSONObj shardKey) const;
    ScopedCollectionFilter _collectionFilter;
    boost::optional<ShardKeyPattern> _keyPattern;
};
}  // namespace mongo

==> percona-server-mongodb_5.0.9.orig.tar.gz: percona-server-mongodb-5.0.9-8/src/mongo/db/exec/shard_filterer_impl.h <==
/**
 *    Copyright (C) 2019-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/db/exec/shard_filterer.h"
#include "mongo/db/matcher/matchable.h"
#include "mongo/db/s/scoped_collection_metadata.h"

namespace mongo {

class ShardFiltererImpl : public ShardFilterer {
public:
    ShardFiltererImpl(ScopedCollectionFilter collectionFilter);

    std::unique_ptr<ShardFilterer> clone() const override;

    DocumentBelongsResult documentBelongsToMe(const BSONObj& doc) const override;
    DocumentBelongsResult documentBelongsToMe(const WorkingSetMember& wsm) const;

    bool keyBelongsToMe(const BSONObj& shardKey) const override {
        return _collectionFilter.keyBelongsToMe(shardKey);
    };

    bool isCollectionSharded() const override {
        return _collectionFilter.isSharded();
    }

    const KeyPattern& getKeyPattern() const override;

private:
    DocumentBelongsResult keyBelongsToMeHelper(const BSONObj& doc) const;

    ScopedCollectionFilter _collectionFilter;
    boost::optional<ShardKeyPattern> _keyPattern;
};
}  // namespace mongo
